@@ -1,4 +1,5 @@
 import logging
+import subprocess
 from pathlib import Path
 from typing import Optional
 
@@ -19,13 +20,13 @@ logger = logging.getLogger(__name__)
 def start_managed_project(
     *,
     template: str,  # CookieCutter Template path or GitHub url
-    directory: str = None,  # Directory name of the CookieCutter Template
     output_dir: Path,  # Target path where CookieCutter should store the result files
+    directory: Optional[str] = None,  # Directory name of the CookieCutter Template
     no_input: bool = False,
     extra_context: Optional[dict] = None,
     replay: Optional[bool] = None,
-    checkout: str = None,
-    password: str = None,
+    checkout: Optional[str] = None,
+    password: Optional[str] = None,  # Optional password to use when extracting the repository
     config_file: Optional[Path] = None,  # Optional path to 'cookiecutter_config.yaml'
 ) -> CookiecutterResult:
     """
@@ -76,11 +77,12 @@ def start_managed_project(
     return result
 
 
-def update_project(
+def update_managed_project(
     project_path: Path,
-    password: str = None,
+    password: Optional[str] = None,
     config_file: Optional[Path] = None,  # CookieCutter config file
     cleanup: bool = True,  # Remove temp files if not exceptions happens
+    no_input: bool = False,  # Prompt the user at command line for manual configuration?
 ) -> Optional[GenerateTemplatePatchResult]:
     """
     Update a existing project by apply git patch from cookiecutter template changes.
@@ -115,6 +117,7 @@ def update_project(
         password=password,
         config_file=config_file,
         cleanup=cleanup,
+        no_input=no_input,
     )
     if not result:
         logger.info('No git patch was created, nothing to apply.')
@@ -125,7 +128,17 @@ def update_project(
     # Apply the patch
 
     patch_file_path = result.patch_file_path
-    git.apply(patch_path=patch_file_path)
+    try:
+        git.apply(patch_path=patch_file_path)
+    except subprocess.CalledProcessError as err:
+        print(err.stdout)
+        if err.returncode == 1:
+            print()
+            print('Seems that the patch was not applied correctly!')
+            print('Hint: run wiggle on the project:')
+            print()
+            print(f'./mp wiggle {project_path}')
+            print()
 
     #############################################################################
     # Update "pyproject.toml" with applied patch information
